# foxes-opt

# _under construction, not yet ready to use. Please stay tuned..._

_Optimization for the [foxes](https://github.com/FraunhoferIWES/foxes) package_

## Installation

Install from pip via
```console
pip install foxes-opt
```
Install from conda-forge via
```console
conda install foxes-opt -c conda-forge
```
